@@ -5,7 +5,7 @@ use Moo;
 use DateTime;
 use Log::Any '$log';
 
-our $VERSION = '0.28'; # VERSION
+our $VERSION = '0.29'; # VERSION
 
 extends 'Finance::Bank::ID::Base';
 
@@ -133,7 +133,6 @@ sub _get_bca_errmsg {
     my $self = shift;
     my $mech = $self->mech;
     my $ct = $mech->content;
-    $self->logger->error("TMP: 1");
     return $1 if $ct =~ m!^<font.+?red><b>(.+)</b></font>!m;
 }
 
@@ -440,7 +439,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -448,7 +447,7 @@ Finance::Bank::ID::BCA - Check your BCA accounts from Perl
 
 =head1 VERSION
 
-version 0.28
+This document describes version 0.29 of Finance::Bank::ID::BCA (from Perl distribution Finance-Bank-ID-BCA), released on 2014-05-17.
 
 =head1 SYNOPSIS
 
@@ -735,8 +734,7 @@ Source repository is at L<https://github.com/sharyanto/perl-Finance-Bank-ID-BCA>
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website
-http://rt.cpan.org/Public/Dist/Display.html?Name=Finance-Bank-ID-BCA
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Finance-Bank-ID-BCA>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -748,7 +746,7 @@ Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Steven Haryanto.
+This software is copyright (c) 2014 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
